@@ -20,8 +20,8 @@ PARAMS: Dict[str, OrgParams] = {
             "aws_saml_url": "home/amazon_aws/0oaj4aow7gPk26Fy6356/272",
             "mfa_provider": "OKTA",
             "mfa_factor_type": "push",
-            "assume_role_ttl": "12h",
-            "session_ttl": "12h",
+            "assume_role_ttl": "1h",
+            "session_ttl": "15m",
         },
         "profiles": {
             "prod": Profile(
