@@ -11,13 +11,14 @@ from .errors import CliError
 
 
 @click.group()
-def sym() -> None:
+@click.option("--debug", is_flag=True)
+def sym(debug: bool) -> None:
     """Access resources managed by Sym workflows.
 
     Use these tools to work with your resources once you've gotten approval in
     Slack.
     """
-    pass
+    AwsOkta.debug = debug
 
 
 @sym.command(short_help="print the version")
